import jwo.processing.utils.*;    // For the sortable key-value class in Jo Wood's ProcessingUtils package.

// Example to demonstrate the use of the SortableKeyValue class. This binds together the key and value for 
// each row in a relational table. This allows the rows in a table to be sorted by value rather than just
// by key.  If a sort by key is required, the class has a static method that will generate a comparator
// that enables key ordering (see "Sort by ID" example below).
//
// The simplest form of table is to store each SortableKeyValue in some kind of list (eg. ArrayList). This
// can then be sorted by passing it to the Collections.sort() method. If some form of lookup beyond a simple
// key-value lookup is required (e.g. relating two tables together), you probably want to store the 
// SortableKeyValue objects in their own HashMap or TreeMap (see distanceTable in the example below).
// Version 1.1, 23rd June, 2009.
// Author Jo Wood.

void setup()
{
  noLoop();
  
  // This example stores the sortable objects in a simple collection.
  ArrayList nameTable = new ArrayList();
  nameTable.add(new SortableKeyValue(25,"Desmond the donkey"));
  nameTable.add(new SortableKeyValue(11,"Sigmund the slow loris"));
  nameTable.add(new SortableKeyValue(80,"Arnold the aardvark"));
  nameTable.add(new SortableKeyValue(6,"Yvelyn the yak"));

  // This example stores the sortable objects in a HashMap
  // Note how the ID is used twice - once for the HashMap key and again as the key in the SortableKeyValue object.
  HashMap distanceTable = new HashMap(); 
  distanceTable.put(25, new SortableKeyValue(25,130.5));
  distanceTable.put(11, new SortableKeyValue(11,73.9));
  distanceTable.put(80, new SortableKeyValue(80,60.2));
  distanceTable.put(6, new SortableKeyValue(6,110.0));
  
  System.out.println("Original order:");
  displayList(nameTable);
    
  System.out.println("Sorted by Name:"); 
  Collections.sort(nameTable);             
  displayList(nameTable);
  
  System.out.println("Sorted by ID:"); 
  Collections.sort(nameTable,SortableKeyValue.getKeyComparator()); 
  displayList(nameTable);
  
  System.out.println("Sorted by distance");
  // Need to convert collection into a List before it can be sorted.
  ArrayList sortedDistances = new ArrayList(distanceTable.values());
  Collections.sort(sortedDistances);
  displayList(sortedDistances); 
}
	

/** Displays all the items in the given collection.
 * @param collection Collection to display.
 */
private void displayList(Collection collection)
{
  Iterator i = collection.iterator();
  while (i.hasNext())
  {
    System.out.println((SortableKeyValue)i.next());
  }
  System.out.println("----------------------\n");
}
